import{_ as o,o as t,c as n,F as s,a as e,b as a}from"./index-bb138b99.js";const l={},c=e("h1",null,"About",-1),i=e("p",null,"Help to manage recuring tasks",-1),r=e("p",null,"Powered by flask, sqlalchemy, vue3",-1),_=e("p",null,"Licence MIT",-1),h=e("p",null,[e("a",{href:"https://gitlab.com/vanillasoft/chores"},"homepage"),a(" open issue if you have any problem. ")],-1),u=e("p",null," I have fun coding this, but i will most likely not maintain this on the long run ",-1);function p(d,m){return t(),n(s,null,[c,i,r,_,h,u],64)}const b=o(l,[["render",p]]);export{b as default};
